import { HttpService } from '@nestjs/axios';
import { CreateDatabaseResponse } from '../interfaces/response/database/create-database.response.interface';
import { DeleteDatabaseResponse } from '../interfaces/response/database/delete-database.response.interface';
import { GetAllDatabaseResponse } from '../interfaces/response/database/get-all-database.response.interface';
import { DatabaseUtil } from '../utils/database.util';
export declare class TDengineDatabaseService {
    private readonly httpService;
    private readonly databaseUtil;
    constructor(httpService: HttpService, databaseUtil: DatabaseUtil);
    /**
     * 创建TDengine数据库
     * @param database 数据库名称
     * @param keep 数据保留时间，单位：天，默认：10年
     * @param ifNotExists 是否仅不存在的时候创建，默认为：否
     * @returns 创建结果
     */
    create(database: string, keep?: number, ifNotExists?: boolean): Promise<CreateDatabaseResponse>;
    /**
     * 删除TDengine数据库
     * @param database 数据库名称
     * @param ifExists 是否仅存在的时候删除，默认为：否
     * @returns 删除结果
     */
    delete(database: string, ifExists?: boolean): Promise<DeleteDatabaseResponse>;
    /**
     * 获取TDengine中所有的数据库列表
     * @returns TDengine 数据库列表
     */
    getAll(): Promise<GetAllDatabaseResponse>;
}
