"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TDengineQueryService = void 0;
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const error_wrapper_decorator_1 = require("../decorators/error-wrapper.decorator");
const query_util_1 = require("../utils/query.util");
let TDengineQueryService = class TDengineQueryService {
    constructor(httpService, queryUtil) {
        this.httpService = httpService;
        this.queryUtil = queryUtil;
    }
    /**
     * 执行SQL查询语句
     * @param sql 执行查询的SQL语句
     * @returns SQL执行结果
     */
    async exec(sql) {
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */, data: this.queryUtil.resolve(data) };
    }
    /**
     * 获取符合条件的数据条数
     * @param database 数据库名称
     * @param table 表名称（超级表、子表、普通表均可）
     * @param condition 查询条件
     * @returns 获取数量sql执行结果
     */
    async count(database, table, condition) {
        const sql = `SELECT count(*) FROM ${database}.${table} WHERE ${condition}`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        const count = this.queryUtil.resolveCount(data);
        return { success: data.status === "succ" /* Success */, data: count };
    }
};
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], TDengineQueryService.prototype, "exec", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String]),
    __metadata("design:returntype", Promise)
], TDengineQueryService.prototype, "count", null);
TDengineQueryService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [axios_1.HttpService, query_util_1.QueryUtil])
], TDengineQueryService);
exports.TDengineQueryService = TDengineQueryService;
