"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TDengineSuperTableService = void 0;
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const error_wrapper_decorator_1 = require("../decorators/error-wrapper.decorator");
let TDengineSuperTableService = class TDengineSuperTableService {
    constructor(httpService) {
        this.httpService = httpService;
    }
    /**
     * 创建超级表
     * @param database 数据库名称
     * @param name 超级表名称
     * @param fieldList 字段列表，不要写**timestamp**字段，框架已经自动在列表最前面插入了此字段。
     * @param tags tag列表
     * @param ifNotExists 是否仅在**不存在此表的时候创建**，默认为：否
     * @returns 超级表创建结果
     */
    async create(database, name, fieldList, tags, ifNotExists = false) {
        const sql = `
      CREATE STABLE ${ifNotExists ? 'IF NOT EXISTS' : ''} 
      ${database}.${name} (ts TIMESTAMP, ${fieldList.map(([field, type]) => `${field} ${type}`).join(', ')})
      TAGS (${tags.map(([tag, type]) => `${tag} ${type}`).join(',')})
    `;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
    /**
     * 删除超级表
     * @param database 数据库名称
     * @param name 超级表名称
     * @param ifExists 是否仅在超级表存在的情况下执行删除，默认为：否
     * @returns 超级表删除结果
     */
    async delete(database, name, ifExists = false) {
        const sql = `DROP STABLE ${ifExists ? 'IF EXISTS' : ''} ${database}.${name}`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
};
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Array, Array, Object]),
    __metadata("design:returntype", Promise)
], TDengineSuperTableService.prototype, "create", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Object]),
    __metadata("design:returntype", Promise)
], TDengineSuperTableService.prototype, "delete", null);
TDengineSuperTableService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [axios_1.HttpService])
], TDengineSuperTableService);
exports.TDengineSuperTableService = TDengineSuperTableService;
