"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TDengineTableService = void 0;
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const error_wrapper_decorator_1 = require("../decorators/error-wrapper.decorator");
let TDengineTableService = class TDengineTableService {
    constructor(httpService) {
        this.httpService = httpService;
    }
    /**
     * 创建表
     * @param database 数据库
     * @param name 表
     * @param fieldList 字段列表
     * @param ifNotExists 是否仅在不存在时创建（默认：false）
     * @returns 表创建结果
     */
    async create(database, name, fieldList, ifNotExists = false) {
        const sql = `
      CREATE TABLE ${ifNotExists ? 'IF NOT EXISTS' : ''} 
      ${database}.${name} (ts TIMESTAMP, ${fieldList.map(([field, type]) => `${field} ${type}`).join(', ')})
    `;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
    async delete(database, name, ifExists = false) {
        const sql = `DROP TABLE ${ifExists ? 'IF EXISTS' : ''} ${database}.${name}`;
        const { data } = await this.httpService.post('/rest/sql', sql).toPromise();
        return { success: data.status === "succ" /* Success */ };
    }
    async findAll(database) {
        const sql = ` SHOW TABLES;`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
    async checkExist(database, name) {
        const sql = `USE ${database}; SHOW TABLES LIKE ${name}`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
};
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Array, Object]),
    __metadata("design:returntype", Promise)
], TDengineTableService.prototype, "create", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Object]),
    __metadata("design:returntype", Promise)
], TDengineTableService.prototype, "delete", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], TDengineTableService.prototype, "findAll", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], TDengineTableService.prototype, "checkExist", null);
TDengineTableService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [axios_1.HttpService])
], TDengineTableService);
exports.TDengineTableService = TDengineTableService;
